<?php
Namespace App\Model\Admin;

use App\Utils\Utils;

/**
 * Provides admin functions for Homegear module management
 *
 */
class HomegearModule
{
    public $hg;
    private $familyConfig = '/etc/homegear/families/';
    private $utils;

    public function __construct(Utils $utils) {
        $this->hg = new \Homegear\Homegear;
        $this->utils = $utils;
    }

    /**
     * List all installed modules
     * 
     * @return array()
     */
    public function listInstalled() {
        $modules = $this->hg->listModules();
        $licenses = $this->hg->getLicenseStates(hexdec('0x7000'));
        // Not checking the var throws a nasty 500 if you dont have easyled installed
        if ($licenses !== false) {
            foreach ($modules as $k => $v) {
                // don't check misc here
                if ($v['FAMILY_ID'] == 254) { continue; }
                $lic = array_search($v['FAMILY_ID'], array_column($licenses,'FAMILY_ID'));
                if ($lic !== false) {
                    $modules[$k]['license'] = '1';
                    if (strstr($licenses[$lic]['LICENSE_KEY'], 'trial')) {
                        $modules[$k]['isTrial'] = date('d.m.Y', strtotime('+30 days', (int)substr($licenses[$lic]['LICENSE_KEY'],5,10)));
                    }
                    $modules[$k]['licenseKey'] = $licenses[$lic]['LICENSE_KEY'];
                }
            }
        }
        return $modules;
    }

    /**
     * Load and activate a module
     * 
     * @return bool
     */
    public function load($module)
    {
        if ($module === null) { return; }
        $config = explode("_",$module);
        $config = preg_replace('/.so$/','',$config[1]);
        if ($this->utils->checkManagementRunning(false)) {
            $this->hg->managementSetConfigurationEntry("families/$config.conf","moduleEnabled","true");
        }
        return $this->hg->loadModule('mod_'.$config.'.so');
    }

    /**
     * Unload and deactivate a module
     * 
     * @return bool
     */
    public function unload($module = null)
    {
        if ($module === null) { return; }
        $config = explode("_",$module);
        $config = preg_replace('/.so$/','',$config[1]);
        if ($this->utils->checkManagementRunning(false)) {
            $this->hg->managementSetConfigurationEntry("families/$config.conf","moduleEnabled","false");
        }
        return $this->hg->unloadModule($module);    
    }

    /**
     * reload and deactivate a module
     * 
     * @return bool
     */
    public function reload($module = null)
    {
        if ($module === null) { return; }
        $config = explode("_",$module);
        $config = preg_replace('/.so$/','',$config[1]);
        if ($this->utils->checkManagementRunning(false)) {
            $this->hg->managementSetConfigurationEntry("families/$config.conf","moduleEnabled","false");
        }
        return $this->hg->reloadModule($module);
    }

    /**
     * Check module license
     * 
     * @return int
     */
    public function checkLicense($family = null, $key = null, $module = null) {
        if ($family === null || $key === null) { return; }
        if ($module === null) {
            $list = $this->hg->listModules();
            foreach ($list as $mod) {
            if ($mod['FAMILY_ID'] == $family) {
                $module = $mod['FILENAME'];
              }
            }
        }
        if (!isset($module)) { return; }
        $return_code = $this->hg->checkLicense((int)hexdec('0x7000'),(int)$family,-1,$key);
        if ($return_code == 0 || $return_code == 1) {
          // load module after successfull activation
          $this->load($module);
        }
        return $return_code;
    }    
}