<?php
Namespace App\Model;

/**
 * Provides base functions for Homegear history and graph data
 *
 */
class HomegearHistory
{
    const componentGroupGridSort = 'sortGroupsGrid';
    const componentGraphGroups = 'GraphGroups';
    const componentGraphConfig = 'configGraphs';
    public $hg;

    public function __construct()
    {
        $this->hg = new \Homegear\Homegear;
    }

    public function checkInfluxDb()
    {
        try {
            $this->hg->influxdbGetDatabase();
        } catch(\Homegear\HomegearException $e) {
            if (stristr($e->getMessage(),'Requested method not found')) {
                return 0;
            }
        }
        return 1;
    }
    
    public function getGraphConfig($graph = null)
    {
        if ($graph === null) { return; }
        $config = $this->hg->getData(self::componentGraphConfig,$graph);
        if ($config !== null) {
            $deviceData = $this->_formatRawMeasurement($graph);
            $config = json_decode($config,true);
            $config['id'] = $graph;
            $config['deviceId'] = $deviceData['deviceid'];
            $config['deviceName'] = $deviceData['name'];
            return $config;
        }
    }

    public function _formatRawMeasurement($data = null) {
        if ($data === null) { return; }
        $graph = explode('_',$data);
        if ($graph[1] == 0 && $graph[2] == 'n') {
            // this is a system variable
            $device = ['ID' => 0, 'NAME' => 'System Variable'];
        } else {
            try {
                $device = $this->hg->getAllConfig(intval($graph[1]))[0];
            } catch(\Homegear\HomegearException $e) {
                return ['id' => $data, 'deviceid' => 'Device not found (deleted?)', 'name' => 'Device not found (deleted?)', 'channel' => $graph[2], 'variable' => $graph[3]];
            }
        }
        return ['id' => $data, 'deviceid' => $device['ID'], 'name' => ($device['NAME'] != '' ? $device['NAME'] : $device['ADDRESS']), 'channel' => $graph[2], 'variable' => $graph[3]];
    }

}