<?php
namespace App\Utils;

use Symfony\Component\HttpFoundation\RequestStack;
use Symfony\Component\Translation\TranslatorInterface;
use Symfony\Component\Routing\RouterInterface;
use Symfony\Component\HttpFoundation\Session\Session;
use \Homegear\Homegear as Homegear;

Class Utils
{
    protected $hg;
    protected $translator;
    protected $request;
    protected $router;

    public function __construct(RequestStack $requestStack, TranslatorInterface $translator, RouterInterface $router)
    {
        $this->hg = new Homegear;
        $this->translator = $translator;
        $this->request = $requestStack;
        $this->router = $router;
    }

    public function checkManagementRunning($fullstatus = true)
    {
        if (call_user_func("Homegear\\Homegear::system.listMethods", "managementGetCommandStatus")) {
            return true;
        }
        if (!$fullstatus) { return false; }
        $current = $this->request->getCurrentRequest()->get('_route');
        return $result = ['status' => '500', 'message' => $this->translator->trans('management.not_running',array(),'admin'), 'callback' => "setTimeout(checkMgmt, 5000, '".$this->router->generate('check', ['type' => 'mgmt'])."', '".$this->router->generate($current)."');"];
    }

    public function checkCa()
    {
        if ($this->checkManagementRunning(false)) {
            return $this->hg->managementCaExists();
        }
        return -1;
    }

    public function getCommandStatus($id) {
        if ($this->checkManagementRunning(false)) {
            $result = $this->hg->managementGetCommandStatus($id);
            while (!$result['finished']) {
                sleep(1);
                $result = $this->hg->managementGetCommandStatus($id);
            }
            return $result;
        }
        return 0;
    }

    public function getDataPath()
    {
        $conf = file_get_contents('/etc/homegear/main.conf');
        preg_match_all('/dataPath = (.+)/',$conf,$result);
        $path = explode(' = ',$result[0][0]);
        return $path[1];
    }

    public function saveToSession($data = false)
    {
        if ($data === false || !is_array($data)) { return; }
        $session = new Session();
        foreach ($data as $key => $value) {
            $session->set("$key", "$value");
        }
    }

    public function checkUpdateRunning($type = false)
    {
        if ($type === false) { return false; }
        $session = new Session();
        $update = $session->get($type);
        if ($update) {
            if ($this->checkManagementRunning(false)) {
                try {
                    $result = $this->hg->managementGetCommandStatus(intval($update));
                } catch(\Homegear\HomegearException $e) {
                    return false;
                }
                if ($result && $result['finished'] !== true) {
                    return true;
                }
                $session-> remove($type);
                return false;
            }
            return -1;
        }
        return -1;
    }

    public function getIpAddresses($hg, $int = false) {
        $tmp = shell_exec('ifconfig');
        $tmp = preg_split("/\n\n/",$tmp);
        foreach ($tmp as $k => $v) {
            if ($v == '') { continue; }
            // TODO: this is not reliable!
            $interface = trim(substr($v, 0, strpos($v, ': flags')));
            if ($interface == '') {
                $interface = trim(substr($v, 0, strpos($v, 'Link')));
            }
            if (strpos($interface,'lo') === false) {
                preg_match('/\d{1,3}\.\d{1,3}\.\d{1,3}\.\d{1,3}/', $v, $ip);
                if (($int !== false) && ($int == $interface) && array_key_exists(0,$ip)) {
                    return $ip[0];
                }
                if (array_key_exists(0,$ip)) {
                    $interfaces[$k]['name'] = $interface;
                    $interfaces[$k]['ip'] = $ip[0];
                }
            }
        }
        return array_values($interfaces);
    }

    public function getHost()
    {
        $host = $_SERVER['HTTP_HOST'];
        if ($_SERVER['SERVER_ADDR'] != $host) {
            if (stristr($host,':')) {
                list($host,$port) = explode(':',$host);
            }
            return $host;
        }
        return $_SERVER['HTTP_HOST'];
    }

    public function getPort()
    {
        $host = $_SERVER['HTTP_HOST'];
        $port = '80';
        if ($_SERVER['SERVER_ADDR'] != $host) {
            $port = '443';
            if (stristr($host,':')) {
                list($host,$port) = explode(':',$host);
            }
        } else {
            if (stristr($host,':')) {
                list($host,$port) = explode(':',$host);
            }
        }
        return $port;
    }
}